@@ -14,11 +14,15 @@ class setup:
         if self.full_error:
             error = traceback.format_exc()
         message = f'{title}: {error}'
-        if self.resend_repeat_errors or error != self.last_error:
-            self.bot.send_message(self.channel, message[:4096])
-            self.last_error = error
         print(message)
         print()
+        if self.resend_repeat_errors or error != self.last_error:
+            try:
+                self.bot.send_message(self.channel, message[:4096])
+                self.last_error = error
+            except Exception as telegram_error:
+                print('Error sending alert message to Telegram:', telegram_error)
+                print()
         if self.raise_error:
             raise Exception('Raiser') from exception
     def send_message(self, *messages):
@@ -26,6 +30,10 @@ class setup:
         for message in messages:
             final_message += message
             final_message += ' '
-        self.bot.send_message(self.channel, final_message)
         print(final_message)
-        print()
\ No newline at end of file
+        print()
+        try:
+            self.bot.send_message(self.channel, final_message)
+        except Exception as telegram_error:
+            print('Error sending message to Telegram:', telegram_error)
+            print()
\ No newline at end of file
